
/*!
 * @file cruizer.h
 * Implements the Control of a Cruizer
 */

#ifndef _CRUIZER_H
#define _CRUIZER_H

#include "playable.h"

// Forward Declaration
class ParticleEmitter;
class ParticleSystem;

class Cruizer : public Playable
{
  public:
    Cruizer(const std::string& fileName);
    Cruizer(const TiXmlElement* root = NULL);
    virtual ~Cruizer();

    virtual void loadParams(const TiXmlElement* root);
    virtual void setPlayDirection(const Quaternion& rot, float speed = 0.0f);
    virtual void enter();
    virtual void leave();

    virtual void postSpawn();
    virtual void leftWorld();

    virtual void collidesWith(WorldEntity* entity, const Vector& location);
    virtual void tick(float dt);
    virtual void draw() const;

    virtual void process(const Event &event);

  private:
    void init();
    void movement(float dt);

  private:
    bool                  bForward;           //!< forward button pressed.
    bool                  bBackward;          //!< backward button pressed.
    bool                  bLeft;              //!< left button pressed.
    bool                  bRight;             //!< right button pressed.
    bool                  bAscend;            //!< ascend button pressed.
    bool                  bDescend;           //!< descend button presses.

    int                   yInvert;
    float                 mouseSensitivity;   //!< the mouse sensitivity

    PNode                 cameraNode;
    float                 cameraLook;
    float                 rotation;

   // Vector                velocity;           //!< the velocity of the Cruizer.
    Quaternion            direction;          //!< the direction of the Cruizer.
    float                 travelSpeed;        //!< the current speed of the Hove (to make soft movement)
    float                 acceleration;       //!< the acceleration of the Cruizer.
    float                 airFriction;        //!< AirFriction.

    float                 rotorSpeed;         //!< the speed of the rotor.
    float                 rotorCycle;         //!< The Cycle the rotor is in.

    float                 airViscosity;

    ParticleEmitter*      burstEmitter;
    ParticleSystem*       burstSystem;
};

#endif /* _CRUIZERS_H */
